@@ -77,8 +77,8 @@ class WikiClient(Wiki):
         return clients
         
     @staticmethod
-    def ofWikiId(wikiId):
-        wikiUser=WikiUser.ofWikiId(wikiId)
+    def ofWikiId(wikiId,lenient=True):
+        wikiUser=WikiUser.ofWikiId(wikiId,lenient=lenient)
         wikibot=WikiClient(wikiUser)
         return wikibot
     
